@@ -1,6 +1,6 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * gog-reg-curve.h :  
+ * gog-reg-curve.h :
  *
  * Copyright (C) 2005 Jean Brefort (jean.brefort@normalesup.org)
  *
@@ -28,11 +28,11 @@ G_BEGIN_DECLS
 
 struct  _GogRegCurve {
 	GogTrendLine	base;
-	
+
 	GogSeries 	  *series;
 	gboolean  	   weighted;
 	GODataVector 	  *weights;
-	GogDatasetElement *bounds;
+	GogDatasetElement *bounds;       /* aliased to include the name as -1 */
 	gboolean	   skip_invalid; /* do not take into account invalid data */
 	int		   ninterp;	 /* how many points to use for display the curve as a vpath */
 	double		  *a;		 /* calculated coefficients, must be allocated by derived class */
@@ -44,7 +44,7 @@ typedef struct {
 	GogTrendLineClass base;
 
 	double 		(*get_value_at) (GogRegCurve *reg_curve, double x);
-	gchar const* 	(*get_equation) (GogRegCurve *reg_curve);
+	char const * 	(*get_equation) (GogRegCurve *reg_curve);
 	void 		(*populate_editor) (GogRegCurve *reg_curve, gpointer table);
 } GogRegCurveClass;
 
